@@ -12,6 +12,8 @@ class SyncAPIResource:
         self._post = client.post
         self._get = client.get
         self._delete = client.delete
+        self._post_without_retry = client.post_without_retry
+        self._get_api_list = client.get_api_list
 
 
 class AsyncAPIResource:
@@ -22,3 +24,5 @@ class AsyncAPIResource:
         self._post = client.post
         self._get = client.get
         self._delete = client.delete
+        self._post_without_retry = client.post_without_retry
+        self._get_api_list = client.get_api_list
